@@ -9,6 +9,7 @@
 #include <KIO/CommandLauncherJob>
 #include <KNotificationJobUiDelegate>
 #include <KPluginFactory>
+#include <KRuntimePlatform>
 
 #include <QDBusConnection>
 #include <QDBusMessage>
@@ -91,8 +92,7 @@ void MobileShellSettings::setNavigationPanelEnabled(bool navigationPanelEnabled)
     group.writeEntry("navigationPanelEnabled", navigationPanelEnabled, KConfigGroup::Notify);
     m_config->sync();
 
-    // TODO: Gesture only mode setting is disabled until we get the kwin effect gesture working: https://invent.kde.org/plasma/plasma-mobile/-/issues/300
-    // updateNavigationBarsInPlasma(navigationPanelEnabled);
+    updateNavigationBarsInPlasma(navigationPanelEnabled);
 }
 
 bool MobileShellSettings::alwaysShowKeyboardToggleOnNavigationPanel() const
@@ -155,6 +155,12 @@ void MobileShellSettings::setConvergenceModeEnabled(bool enabled)
 
 void MobileShellSettings::updateNavigationBarsInPlasma(bool navigationPanelEnabled)
 {
+    // Do not update panels when not in Plasma Mobile
+    bool isMobilePlatform = KRuntimePlatform::runtimePlatform().contains("phone");
+    if (!isMobilePlatform) {
+        return;
+    }
+
     auto message = QDBusMessage::createMethodCall(QLatin1String("org.kde.plasmashell"),
                                                   QLatin1String("/PlasmaShell"),
                                                   QLatin1String("org.kde.PlasmaShell"),
